==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/DefaultSegmentDeliveryConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DefaultSegmentDeliveryConfiguration(
    baseUrl: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration = {
    import DefaultSegmentDeliveryConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
      .builder()
      .optionallyWith(
        baseUrl.map(value => __string.unwrap(value): java.lang.String)
      )(_.baseUrl)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration.ReadOnly =
    zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration
      .wrap(buildAwsValue())
}
object DefaultSegmentDeliveryConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration =
      zio.aws.mediatailor.model
        .DefaultSegmentDeliveryConfiguration(baseUrl.map(value => value))
    def baseUrl: Option[__string]
    def getBaseUrl: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("baseUrl", baseUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
  ) extends zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration.ReadOnly {
    override val baseUrl: Option[__string] = scala
      .Option(impl.baseUrl())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
  ): zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/DefaultSegmentDeliveryConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DefaultSegmentDeliveryConfiguration(
    baseUrl: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration = {
    import DefaultSegmentDeliveryConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
      .builder()
      .optionallyWith(baseUrl.map(value => value: java.lang.String))(_.baseUrl)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration.ReadOnly =
    zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration
      .wrap(buildAwsValue())
}
object DefaultSegmentDeliveryConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration =
      zio.aws.mediatailor.model
        .DefaultSegmentDeliveryConfiguration(baseUrl.map(value => value))
    def baseUrl: Option[__string]
    def getBaseUrl: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("baseUrl", baseUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
  ) extends zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration.ReadOnly {
    override val baseUrl: Option[__string] =
      scala.Option(impl.baseUrl()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DefaultSegmentDeliveryConfiguration
  ): zio.aws.mediatailor.model.DefaultSegmentDeliveryConfiguration.ReadOnly =
    new Wrapper(impl)
}
